@@ -12,7 +12,7 @@ from undouble.undouble import (
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '1.2.8'
+__version__ = '1.2.9'
 
 # module level doc-string
 __doc__ = """
@@ -62,9 +62,10 @@ Example
 >>> # Move the images
 >>> model.move()
 
-
 References
 ----------
-https://github.com/erdogant/undouble
+* Blog: https://towardsdatascience.com/detection-of-duplicate-images-using-image-hash-functions-4d9c53f04a75
+* Github: https://github.com/erdogant/undouble
+* Documentation: https://erdogant.github.io/undouble/
 
 """
