@@ -37,7 +37,7 @@ class Undouble():
 
     Description
     -----------
-    Python package undouble is to detect (near-)identical images.
+    Python package undouble is to detect (near-)identical images based on image hashes.
 
     The following steps are taken:
         1. Read recursively all images from directory with the specified extensions.
@@ -53,6 +53,7 @@ class Undouble():
         * 'phash': Perceptual hash
         * 'dhash': Difference hash
         * 'whash-haar': Haar wavelet hash
+        * 'crop-resistant-hash': Crop resistant hash
     targetdir : str, (default: None)
         Directory to read the images.
     hash_size : integer (default: 8)
@@ -104,6 +105,9 @@ class Undouble():
 
     References
     ----------
+    * Blog: https://towardsdatascience.com/detection-of-duplicate-images-using-image-hash-functions-4d9c53f04a75
+    * Github: https://github.com/erdogant/undouble
+    * Documentation: https://erdogant.github.io/undouble/
     * https://content-blockchain.org/research/testing-different-image-hash-functions/
 
     """
@@ -147,7 +151,7 @@ class Undouble():
         if return_results:
             return self.results
 
-    def compute_hash(self, method=None, hash_size=None, return_dict=False):
+    def compute_hash(self, method=None, hash_size=8, return_dict=False):
         """Compute the hash for each image.
 
         Parameters
@@ -421,7 +425,7 @@ class Undouble():
         >>> model = Undouble()
         >>>
         >>> # Import example data
-        >>> # targetdir = model.import_example(data='flowers')
+        >>> targetdir = model.import_example(data='flowers')
         >>>
         >>> # Importing the files files from disk, cleaning and pre-processing
         >>> model.import_data(r'./undouble/data/flower_images/')
@@ -429,6 +433,9 @@ class Undouble():
         >>> # Compute image-hash
         >>> model.compute_hash(method='phash', hash_size=6)
         >>>
+        >>> # Hashes are stored in the result dict.
+        >>> model.results['img_hash_bin']
+        >>>
         >>> Plot the image-hash for a set of indexes
         >>> model.plot_hash(idx=[0, 1])
         >>>
@@ -530,7 +537,7 @@ class Undouble():
             raise Exception(logger.error('Results missing! Hint: try to first use the model.group() functionality'))
 
     def compute_imghash(self, img, hash_size=None, to_array=False):
-        """Compute hash.
+        """Compute image hash per image.
 
         Parameters
         ----------
@@ -542,6 +549,36 @@ class Undouble():
             True: Return the hash-array in the same size as the scaled image.
             False: Return the hash-image vector.
 
+        Examples
+        --------
+        >>> from undouble import Undouble
+        >>> import matplotlib.pyplot as plt
+        >>>
+        >>> # Initialize with method
+        >>> model = Undouble(method='ahash')
+        >>>
+        >>> # Import flowers example
+        >>> X = model.import_example(data='flowers')
+        >>> imgs = model.import_data(X, return_results=True)
+        >>>
+        >>> # Compute hash for a single image
+        >>> hashs = model.compute_imghash(imgs['img'][0], to_array=False, hash_size=8)
+        >>>
+        >>> # The hash is a binairy array or vector.
+        >>> print(hashs)
+        >>>
+        >>> # Plot the image using the undouble plot_hash functionality
+        >>> model.results['img_hash_bin']
+        >>> model.plot_hash(idx=0)
+        >>>
+        >>> # Plot the image
+        >>> fig, ax = plt.subplots(1, 2, figsize=(8,8))
+        >>> ax[0].imshow(imgs['img'][0])
+        >>> ax[1].imshow(hashs[0])
+        >>>
+        >>> # Compute hash for multiple images
+        >>> hashs = model.compute_imghash(imgs['img'][0:10], to_array=False, hash_size=8)
+
         Returns
         -------
         imghash : numpy-array
@@ -564,6 +601,8 @@ class Undouble():
         else:
             hashes = list(map(lambda x: x.reshape(hash_size,hash_size), hashes))
 
+        # Store the hash
+        self.results['img_hash_bin'] = hashes
         return hashes
 
     def bin2hex(self):
